EXPORTS
	__20CEventCallbackFilter @ 1 NONAME R3UNUSED ; CEventCallbackFilter::CEventCallbackFilter(void)
	AddHeaderL__12CDriverTransG8RStringFQ212CDriverTrans11THdrValTypeG7RString @ 2 NONAME ; CDriverTrans::AddHeaderL(RStringF, CDriverTrans::THdrValType, RString)
	AddHeaderWithParamL__12CDriverTransG8RStringFQ212CDriverTrans11THdrValTypeG7RStringT1T2T3 @ 3 NONAME ; CDriverTrans::AddHeaderWithParamL(RStringF, CDriverTrans::THdrValType, RString, RStringF, CDriverTrans::THdrValType, RString)
	AddRequestSessionHeaderL__15CWspEventDriverG8RStringFQ212CDriverTrans11THdrValTypeG7RString @ 4 NONAME ; CWspEventDriver::AddRequestSessionHeaderL(RStringF, CDriverTrans::THdrValType, RString)
	AddRequestSessionHeaderWithParamL__15CWspEventDriverG8RStringFQ212CDriverTrans11THdrValTypeG7RStringT1T2T3 @ 5 NONAME ; CWspEventDriver::AddRequestSessionHeaderWithParamL(RStringF, CDriverTrans::THdrValType, RString, RStringF, CDriverTrans::THdrValType, RString)
	Cancel__12CDriverTrans @ 6 NONAME R3UNUSED ; CDriverTrans::Cancel(void)
	CleanUp__19CDriverDataSupplierPv @ 7 NONAME R3UNUSED ; CDriverDataSupplier::CleanUp(void *)
	Close__12CDriverTrans @ 8 NONAME R3UNUSED ; CDriverTrans::Close(void)
	CreateItemL__20CEventCallbackFilterRC7TDesC16T1 @ 9 NONAME ; CEventCallbackFilter::CreateItemL(TDesC16 const &, TDesC16 const &)
	DumpResponseBody__12CDriverTransR14MConsoleDumper @ 10 NONAME R3UNUSED ; CDriverTrans::DumpResponseBody(MConsoleDumper &)
	DumpResponseHeadersL__12CDriverTransR14MConsoleDumper @ 11 NONAME R3UNUSED ; CDriverTrans::DumpResponseHeadersL(MConsoleDumper &)
	DumpSessionHeadersL__15CWspEventDriverR14MConsoleDumper @ 12 NONAME R3UNUSED ; CWspEventDriver::DumpSessionHeadersL(MConsoleDumper &)
	FetchFromItemStore__C20CEventCallbackFilterRC7TDesC16R15TStoredItemBase @ 13 NONAME R3UNUSED ; CEventCallbackFilter::FetchFromItemStore(TDesC16 const &, TStoredItemBase &) const
	FlushItemStore__20CEventCallbackFilter @ 14 NONAME R3UNUSED ; CEventCallbackFilter::FlushItemStore(void)
	GetBody__12CDriverTrans @ 15 NONAME R3UNUSED ; CDriverTrans::GetBody(void)
	GetConnectionProperties__15CWspEventDriverR8RStringFT1RiN23T1T1T3 @ 16 NONAME ; CWspEventDriver::GetConnectionProperties(RStringF &, RStringF &, int &, int &, int &, RStringF &, RStringF &, int &)
	GetHeaderL__12CDriverTransG8RStringFRQ212CDriverTrans11THdrValTypeR7RStringi @ 17 NONAME ; CDriverTrans::GetHeaderL(RStringF, CDriverTrans::THdrValType &, RString &, int)
	GetStatusCode__12CDriverTrans @ 18 NONAME R3UNUSED ; CDriverTrans::GetStatusCode(void)
	LookUpItem__C20CEventCallbackFilterG15TStoredItemBaseR7TPtrC16 @ 19 NONAME R3UNUSED ; CEventCallbackFilter::LookUpItem(TStoredItemBase, TPtrC16 &) const
	MCIS_Reserved__20CEventCallbackFilter @ 20 NONAME R3UNUSED ; CEventCallbackFilter::MCIS_Reserved(void)
	MoreRequestBodyDataL__12CDriverTrans @ 21 NONAME R3UNUSED ; CDriverTrans::MoreRequestBodyDataL(void)
	NewL__12CDriverTransG12RHTTPSessionG8RStringFG6TUriC8R15MDriverTransObsR24MHTTPTransactionCallbackRC7TDesC16 @ 22 NONAME ; CDriverTrans::NewL(RHTTPSession, RStringF, TUriC8, MDriverTransObs &, MHTTPTransactionCallback &, TDesC16 const &)
	NewL__15CWspEventDriverR20CEventCallbackFilterRC7TDesC16 @ 23 NONAME R3UNUSED ; CWspEventDriver::NewL(CEventCallbackFilter &, TDesC16 const &)
	NewL__19CDriverDataSupplierR11CChatEngine @ 24 NONAME R3UNUSED ; CDriverDataSupplier::NewL(CChatEngine &)
	OpenTransactionL__15CWspEventDriverG8RStringFG6TUriC8RC7TDesC16 @ 25 NONAME ; CWspEventDriver::OpenTransactionL(RStringF, TUriC8, TDesC16 const &)
	Reset__15CWspEventDriver @ 26 NONAME R3UNUSED ; CWspEventDriver::Reset(void)
	SessionConnectL__15CWspEventDriver @ 27 NONAME R3UNUSED ; CWspEventDriver::SessionConnectL(void)
	SessionDisconnectL__15CWspEventDriver @ 28 NONAME R3UNUSED ; CWspEventDriver::SessionDisconnectL(void)
	SetClientMessageSizeL__15CWspEventDriverUl @ 29 NONAME R3UNUSED ; CWspEventDriver::SetClientMessageSizeL(unsigned long)
	SetConnectionPropertiesL__15CWspEventDriverG8RStringFT1iiiT1T1i @ 30 NONAME ; CWspEventDriver::SetConnectionPropertiesL(RStringF, RStringF, int, int, int, RStringF, RStringF, int)
	SetMethodMORL__15CWspEventDriverUl @ 31 NONAME R3UNUSED ; CWspEventDriver::SetMethodMORL(unsigned long)
	SetServerMessageSizeL__15CWspEventDriverUl @ 32 NONAME R3UNUSED ; CWspEventDriver::SetServerMessageSizeL(unsigned long)
	SetTransConverter__20CEventCallbackFilterR15MTransConverter @ 33 NONAME R3UNUSED ; CEventCallbackFilter::SetTransConverter(MTransConverter &)
	SetUseAcknowledgementsL__15CWspEventDriver @ 34 NONAME R3UNUSED ; CWspEventDriver::SetUseAcknowledgementsL(void)
	SetUseSuspendResumeL__15CWspEventDriver @ 35 NONAME R3UNUSED ; CWspEventDriver::SetUseSuspendResumeL(void)
	StoreItemL__20CEventCallbackFilterRC7TDesC16G15TStoredItemBase @ 36 NONAME R3UNUSED ; CEventCallbackFilter::StoreItemL(TDesC16 const &, TStoredItemBase)
	StringPool__15CWspEventDriver @ 37 NONAME R3UNUSED ; CWspEventDriver::StringPool(void)
	SubmitL__12CDriverTrans @ 38 NONAME R3UNUSED ; CDriverTrans::SubmitL(void)
	TransId__C12CDriverTrans @ 39 NONAME R3UNUSED ; CDriverTrans::TransId(void) const
	Trans__C12CDriverTrans @ 40 NONAME R3UNUSED ; CDriverTrans::Trans(void) const
	"_._12CDriverTrans" @ 41 NONAME R3UNUSED ; CDriverTrans::~CDriverTrans(void)
	"_._15CWspEventDriver" @ 42 NONAME R3UNUSED ; CWspEventDriver::~CWspEventDriver(void)
	"_._20CEventCallbackFilter" @ 43 NONAME R3UNUSED ; CEventCallbackFilter::~CEventCallbackFilter(void)
	AddBody__12CDriverTransR17MHTTPDataSupplier @ 44 NONAME R3UNUSED ; CDriverTrans::AddBody(MHTTPDataSupplier &)

